@@ -78,6 +78,8 @@ EOF
 	    extract_cmd="tar --bzip2 -xf";;
 	*.tgz|*.tar.gz)
 	    extract_cmd="tar xfz";;
+	*.zip)
+	    extract_cmd="unzip -q";;
 	*)
 	    extract_cmd=sh
     esac
