@@ -2,8 +2,8 @@
 function ibm_j2sdk_detect() {
   local found=
   eval $(dpkg-architecture)
-  case "$DEB_BUILD_GNU_TYPE" in
-    "i386-linux")
+  case "${DEB_BUILD_ARCH:-$DEB_BUILD_GNU_TYPE}" in
+    i386|i386-linux)
       case "$archive_name" in
         "IBMJava2-SDK-131.tgz") # SUPPORTED
 	    j2se_version=1.3.1
@@ -17,7 +17,7 @@ function ibm_j2sdk_detect() {
 	    ;;
       esac
       ;;
-    "x86_64-linux")
+    amd64|x86_64-linux)
       case "$archive_name" in
         "IBMJava2-SDK-AMD64-142.x86_64.tgz") # SUPPORTED
 	    j2se_version=1.4.2
@@ -26,7 +26,7 @@ function ibm_j2sdk_detect() {
 	    ;;
       esac
       ;;
-    "powerpc-linux")
+    powerpc|powerpc-linux)
       case "$archive_name" in
         "IBMJava2-SDK-131.ppc.tgz") # SUPPORTED
 	    j2se_version=1.3.1
@@ -45,7 +45,7 @@ function ibm_j2sdk_detect() {
 	    ;;
       esac
       ;;
-    "powerpc64-linux")
+    powerpc64|powerpc64-linux)
       case "$archive_name" in
         "IBMJava2-SDK-142.ppc64.tgz") # SUPPORTED
 	    j2se_version=1.4.2
@@ -54,7 +54,7 @@ function ibm_j2sdk_detect() {
 	    ;;
       esac
       ;;
-    "s390-linux")
+    s390|s390-linux)
       case "$archive_name" in
         "IBMJava2-SDK-142.s390.tgz") # SUPPORTED
 	    j2se_version=1.4.2
