@@ -18,7 +18,7 @@ Replaces: ${j2se_package}debian
 Description: $j2se_title
  The Java(TM) 2 SDK is a development environment for building
  applications, applets, and components that can be deployed on the
- Java platform.
+ Java(TM) platform.
  .
  The Java(TM) 2 SDK software includes tools useful for developing and
  testing programs written in the Java programming language and running
